pub enum Status {
Unknown,
BeingDetermined,
Clean,
Built,
Building,
Failed,
Marked,
Unready,
Dirty,
}Expand description
The status of a rule.
Variants
Unknown
This is the default status.
BeingDetermined
We are still deciding whether this needs to be built.
Clean
We have determined that the rule doesn’t need to run.
Built
The rule already ran.
Building
The rule is currently being built.
Failed
The rule failed.
Marked
This is used to indicate that specific rules are requested to be built.
Unready
A rule cannot yet be built, because one of its inputs still needs to be built.
Dirty
This rule needs to be run.
Implementations